@@ -1,15 +1,15 @@
 /* imagdiff:  Compares two image files and writes differences to a third image
    file, using Imlib2 as an I/O and computational engine.
 
-   Copyright (C) 2018-2019 by Brian E. Lindholm.  This file is part of the
+   Copyright (C) 2018-2020 by Brian E. Lindholm.  This file is part of the
    littleutils utility set.
 
-   The pngstrip utility is free software; you can redistribute it and/or modify
+   The imagdiff utility is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 3, or (at your option) any later
    version.
 
-   The pngstrip utility is distributed in the hope that it will be useful, but
+   The imagdiff utility is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.
@@ -18,21 +18,22 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
-#define X_DISPLAY_MISSING
-#include <Imlib2.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <config.h>
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
-#else
-#define OPTEND EOF
+#define X_DISPLAY_MISSING
+#include <stdio.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+# define OPTEND -1
+#else
+# define OPTEND EOF
+#endif
 #ifdef HAVE_GETOPT_H
-#include <getopt.h>
+# include <getopt.h>
 #endif
 
 #ifdef __MINGW32__
@@ -41,6 +42,8 @@ extern char *optarg;
 extern int optind;
 #endif
 
+#include <Imlib2.h>
+
 #define MODE_GRAY 1
 #define MODE_LIGHT_GRAY 2
 #define MODE_DARK_GRAY 3
