@@ -33,32 +33,38 @@
    notice and this permission notice appear in supporting documentation.  This
    software is provided "as is" without express or implied warranty.
 
-   Derived "imagsize" program Copyright (C)2004-2005 by Brian Lindholm.  All
+   Derived "imagsize" program Copyright (C)2004-2020 by Brian Lindholm.  All
    rights reserved.  Redistribution is permitted as described as above.  */
 
 
 /* various includes */
 
-#include "../config.h"
-#include <limits.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <sys/stat.h>
+#include <config.h>
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
-#else
-#define OPTEND EOF
+#include <limits.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#include <stdio.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+# define OPTEND -1
+#else
+# define OPTEND EOF
+#endif
 #ifdef HAVE_GETOPT_H
-#include <getopt.h>
+# include <getopt.h>
 #endif
 
 #if HAVE_INTTYPES_H
-#include <inttypes.h>
+# include <inttypes.h>
 #endif
 
 #ifdef __MINGW32__
@@ -72,7 +78,7 @@ unsigned short _djstat_flags = 63;  /* Speed up stat command for DJGPP */
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 256
+# define PATH_MAX 256
 #endif
 
 /* Define a few JPEG markers. */
