@@ -15,31 +15,33 @@
  * This may be useful as an example of the minimum logic needed to parse
  * JPEG markers.
  *
- * Modifications Copyright (C) 2004-2013 by Brian Lindholm.  All rights
+ * Modifications Copyright (C) 2004-2020 by Brian Lindholm.  All rights
  * reserved except as specified above.
  */
 
-#include "../config.h"
+#include <config.h>
 
 #ifdef HAVE_LOCALE_H
-#include <locale.h>		/* Bill Allombert: use locale for isprint */
+# include <locale.h>		/* Bill Allombert: use locale for isprint */
 #endif
-
 #include <ctype.h>		/* to declare isupper(), tolower() */
 #include <limits.h>		/* to determine PATH_MAX */
 #include <stdio.h>		/* other I/O functions */
-#include <stdlib.h>		/* other I/O functions */
-#include <string.h>		/* other I/O functions */
-
-#ifdef HAVE_GETOPT_H
-#include <getopt.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>		/* other I/O functions */
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>		/* other I/O functions */
 #endif
 
+#ifdef HAVE_GETOPT_H
+# include <getopt.h>
+#endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #ifdef __MINGW32__
@@ -49,7 +51,7 @@ extern int optind;
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 256
+# define PATH_MAX 256
 #endif
 
 /*
