@@ -1,6 +1,6 @@
 // libpngrecolor.c - part of pngrecolor
 // Copyright (C) 2010 by Jason Summers (from original libpngrewrite.c)
-// Modifications (C) 2013-2014 by Brian Lindholm
+// Modifications (C) 2013-2020 by Brian Lindholm
 //   [1] Renamed from "pngrewrite" to "pngrecolor" at avoid confusion with
 //       original program.
 //   [2] Modified palette comparison routine to ensure a *unique* sorting.
@@ -9,21 +9,27 @@
 //   These modifications may be used without restriction.
 
 #if defined(_WIN32) && !defined(__GNUC__) && !defined(PNGRW_WINDOWS)
-#define PNGRW_WINDOWS
+# define PNGRW_WINDOWS
 #endif
 
 #ifdef PNGRW_WINDOWS
-#include <tchar.h>
-#include <strsafe.h>
+# include <tchar.h>
+# include <strsafe.h>
 #endif
 
+#include <config.h>
+
 #include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
 #include <stdarg.h>
 
 #ifdef PNGRW_WINDOWS
-#include <search.h> /* for qsort */
+# include <search.h> /* for qsort */
 #endif
 
 #include <png.h>
@@ -31,11 +37,11 @@
 #include "libpngrecolor.h"
 
 #ifdef PNGRW_WINDOWS
-#define PNGRW_TEXT _T
+# define PNGRW_TEXT _T
 #else
-#define PNGRW_TEXT(x) x
-#define _tfopen fopen
-#define _ftprintf fprintf
+# define PNGRW_TEXT(x) x
+# define _tfopen fopen
+# define _ftprintf fprintf
 #endif
 
 #define PNGREWRITEVERSION  PNGRW_TEXT("1.4.0")
