@@ -18,13 +18,16 @@
 
 /* Written by David Madore, considerably copypasting from Scott G. Miller's
    sha1.c.  Modifications for portability and partial file reads by Brian
-   Lindholm, 2007-2018.  */
+   Lindholm, 2007-2020.  */
+
+#include <config.h>
 
-#include "../config.h"
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>
 #endif
+
 #include "sha512.h"
+
 #ifdef HAVE_STDALIGN_H
 # include <stdalign.h>
 #endif
@@ -183,9 +186,10 @@ sha384_finish_ctx (struct sha512_ctx *ctx, void *resbuf)
 }
 
 /* Compute message digest for bytes read from STREAM using algorithm ALG.
-   Write the message digest into RESBLOCK, which contains HASHLEN bytes.
-   The initial and finishing operations are INIT_CTX and FINISH_CTX.
-   Return zero if and only if successful.  */
+   Write the message digest into RESBLOCK, which contains HASHLEN bytes.  The
+   initial and finishing operations are INIT_CTX and FINISH_CTX.  Return zero
+   if and only if successful.  Readbytes == -1 implies whole file.  */
+
 static int
 shaxxx_stream (FILE *stream, char const *alg, void *resblock, off_t readbytes,
                ssize_t hashlen, void (*init_ctx) (struct sha512_ctx *),
@@ -199,7 +203,14 @@ shaxxx_stream (FILE *stream, char const *alg, void *resblock, off_t readbytes,
   struct sha512_ctx ctx;
   init_ctx (&ctx);
   size_t sum, target;
-  off_t total = (off_t) 0;
+  off_t total = 0;
+
+  /* Jump to end for readbytes == 0.  */
+  if (readbytes == 0)
+    {
+      sum = 0;
+      goto process_partial_block;
+    }
 
   /* Iterate over full file contents.  */
   while (1)
@@ -208,8 +219,8 @@ shaxxx_stream (FILE *stream, char const *alg, void *resblock, off_t readbytes,
          computation function processes the whole buffer so that with the
          next round of the loop another block can be read.  */
       size_t n;
-      if ((readbytes < (off_t) 1) || ((readbytes - total) > (off_t) BLOCKSIZE))
-        target = BLOCKSIZE;
+      if ((readbytes < 0) || ((readbytes - total) > (off_t) BLOCKSIZE))
+        target = (size_t) BLOCKSIZE;
       else
         target = (size_t) (readbytes - total);
       sum = 0;
@@ -222,7 +233,7 @@ shaxxx_stream (FILE *stream, char const *alg, void *resblock, off_t readbytes,
              We need to avoid a subsequent fread() as EOF may
              not be sticky.  For details of such systems, see:
              https://sourceware.org/bugzilla/show_bug.cgi?id=1190  */
-          if (feof (stream))
+          if (((off_t) sum >= target) || feof (stream))
             goto process_partial_block;
 
           n = fread (buffer + sum, 1, target - sum, stream);
@@ -246,10 +257,6 @@ shaxxx_stream (FILE *stream, char const *alg, void *resblock, off_t readbytes,
         }
       total += (off_t) sum;
 
-      /* If end of file is reached, end the loop.  */
-      if ((n == 0) || (sum == 0) || (total == readbytes))
-        goto process_partial_block;
-
       /* Process buffer with BLOCKSIZE bytes.  Note that
                         BLOCKSIZE % 128 == 0
        */
