@@ -1,7 +1,7 @@
 /* tempname:  Creates a unique temporary file (or filename) for use by shell
    scripts.
 
-   Copyright (C) 2004-2018 by Brian Lindholm.
+   Copyright (C) 2004-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The tempname utility is free software; you can redistribute it and/or
@@ -18,25 +18,33 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
+#include <config.h>
+
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
 #include <time.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 #include <fcntl.h>
 #include <errno.h>
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
-
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #ifdef __MINGW32__
@@ -138,7 +146,7 @@ rand_seed ()
   time_t junk;
   unsigned short seed[3];
 
-  /* pre-populate arracy for seed using /dev/urandom */
+  /* pre-populate array for seed using /dev/urandom */
   URANDOM = open("/dev/urandom", O_RDONLY);
   if (URANDOM < 0) {
     urandom_worked = 0;
