@@ -1,6 +1,6 @@
 /* rep_hard:  Prints out size/inode/device numbers for the specified files.
 
-   Copyright (C) 2006-2013 by Brian Lindholm.
+   Copyright (C) 2006-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The rep_hard utility is free software; you can redistribute it and/or modify
@@ -17,26 +17,32 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
+#include <config.h>
+
 #include <limits.h>
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/stat.h>
-
-#ifdef HAVE_GETOPT_H
-#include <getopt.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
 #endif
 
+#ifdef HAVE_GETOPT_H
+# include <getopt.h>
+#endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #if HAVE_INTTYPES_H
-#include <inttypes.h>
+# include <inttypes.h>
 #endif
 
 #ifdef __MINGW32__
@@ -51,7 +57,7 @@ unsigned short _djstat_flags = 63;
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 4096
+# define PATH_MAX 4096
 #endif
 
 char *sizefmt_ps =
